#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bzlib
version:              0.5.2.0
visibility:           public
id:                   bzlib-0.5.2.0-FqrlR9iXHKjHTDRsSgeHPa
key:                  bzlib-0.5.2.0-FqrlR9iXHKjHTDRsSgeHPa
license:              BSD-3-Clause
copyright:            (c) 2006-2015 Duncan Coutts
maintainer:           Duncan Coutts <duncan@community.haskell.org>
author:               Duncan Coutts <duncan@community.haskell.org>
synopsis:             Compression and decompression in the bzip2 format
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the bz2 C library so it has high
    performance.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full bzip2 feature set.

category:             Codec
abi:                  a0986a445fc8720fd162754770ed81d2
exposed:              True
exposed-modules:
    Codec.Compression.BZip Codec.Compression.BZip.Internal

hidden-modules:       Codec.Compression.BZip.Stream
import-dirs:          /usr/lib/ghc-9.6.6/site-local/bzlib-0.5.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bzlib-0.5.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bzlib-0.5.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bzlib
hs-libraries:         HSbzlib-0.5.2.0-FqrlR9iXHKjHTDRsSgeHPa
extra-libraries:      bz2
includes:             bzlib.h
depends:              base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-bzlib/html/bzlib.haddock
haddock-html:         /usr/share/doc/haskell-bzlib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

